==> seedsui-react-2.6.2.tgz: package/es/Handsign/Handsign.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Instance from './instance.js';

var Handsign = (_temp = _class = function (_Component) {
  _inherits(Handsign, _Component);

  function Handsign(props) {
    _classCallCheck(this, Handsign);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Handsign.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (this.instance) {
      if (prevProps.strokeStyle !== this.props.strokeStyle) {
        this.instance.setStrokeStyle(this.props.strokeStyle);
      }
      if (prevProps.lineWidth !== this.props.lineWidth) {
        this.instance.setLineWidth(this.props.lineWidth);
      }
      if (prevProps.quality !== this.props.quality) {
        this.instance.setQuality(this.props.quality);
      }
      if (prevProps.suffix !== this.props.suffix) {
        this.instance.setSuffix(this.props.suffix);
      }
    }
  };

  Handsign.prototype.componentDidMount = function componentDidMount() {
    if (this.instance) return;
    var instance = new Instance(this.$el, {
      strokeStyle: this.props.strokeStyle,
      lineWidth: this.props.lineWidth,
      quality: this.props.quality,
      suffix: this.props.suffix
    });
    this.instance = instance;
  };

  Handsign.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        strokeStyle = _props.strokeStyle,
        lineWidth = _props.lineWidth,
        quality = _props.quality,
        width = _props.width,
        height = _props.height,
        style = _props.style,
        className = _props.className,
        others = _objectWithoutProperties(_props, ['strokeStyle', 'lineWidth', 'quality', 'width', 'height', 'style', 'className']);

    return React.createElement(
      'canvas',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: className, style: style, width: width, height: height }, others),
      'Canvas\u753B\u677F'
    );
  };

  return Handsign;
}(Component), _class.defaultProps = {
  strokeStyle: '#000',
  lineWidth: 3,
  quality: 0.92,
  width: 300,
  height: 300
}, _temp);
export { Handsign as default };
Handsign.propTypes = process.env.NODE_ENV !== "production" ? {
  strokeStyle: PropTypes.string,
  lineWidth: PropTypes.number,
  quality: PropTypes.number,
  suffix: PropTypes.string,
  // 不能使用style制定宽高,canvas用style的width|height会导致绘图位置不正确
  width: PropTypes.number, // 宽度
  height: PropTypes.number, // 高度
  style: PropTypes.object,
  className: PropTypes.string
} : {};

==> seedsui-react-2.7.9.tgz: package/es/Handsign/Handsign.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Instance from './instance.js';

var Handsign = (_temp = _class = function (_Component) {
  _inherits(Handsign, _Component);

  function Handsign(props) {
    _classCallCheck(this, Handsign);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Handsign.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (this.instance) {
      if (prevProps.strokeStyle !== this.props.strokeStyle) {
        this.instance.setStrokeStyle(this.props.strokeStyle);
      }
      if (prevProps.lineWidth !== this.props.lineWidth) {
        this.instance.setLineWidth(this.props.lineWidth);
      }
      if (prevProps.quality !== this.props.quality) {
        this.instance.setQuality(this.props.quality);
      }
      if (prevProps.suffix !== this.props.suffix) {
        this.instance.setSuffix(this.props.suffix);
      }
    }
  };

  Handsign.prototype.componentDidMount = function componentDidMount() {
    if (this.instance) return;
    var instance = new Instance(this.$el, {
      strokeStyle: this.props.strokeStyle,
      lineWidth: this.props.lineWidth,
      quality: this.props.quality,
      suffix: this.props.suffix
    });
    this.instance = instance;
  };

  Handsign.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        strokeStyle = _props.strokeStyle,
        lineWidth = _props.lineWidth,
        quality = _props.quality,
        width = _props.width,
        height = _props.height,
        others = _objectWithoutProperties(_props, ['strokeStyle', 'lineWidth', 'quality', 'width', 'height']);

    return React.createElement(
      'canvas',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { width: width, height: height }),
      'Canvas\u753B\u677F'
    );
  };

  return Handsign;
}(Component), _class.defaultProps = {
  strokeStyle: '#000',
  lineWidth: 3,
  quality: 0.92,
  width: 300,
  height: 300
}, _temp);
export { Handsign as default };
Handsign.propTypes = process.env.NODE_ENV !== "production" ? {
  strokeStyle: PropTypes.string,
  lineWidth: PropTypes.number,
  quality: PropTypes.number,
  suffix: PropTypes.string,
  // 不能使用style制定宽高,canvas用style的width|height会导致绘图位置不正确
  width: PropTypes.number, // 宽度
  height: PropTypes.number // 高度
} : {};
